# BooLEVARD

[![Logo](https://raw.githubusercontent.com/farinasm/boolevard/main/docs/Logo.svg)](https://github.com/farinasm/boolevard/)

[![PyPI version](https://img.shields.io/pypi/v/boolevard)](PYPIPACKAGE)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/farinasm/boolevard/blob/main/LICENSE/)
[![Documentation](https://img.shields.io/badge/docs-latest-brightgreen.svg)](https://github.com/farinasm/boolevard/)

BooLEVARD is a Python package designed to compute the number of paths leading to node activations or inactivations in Boolean models.

## Features
- Import Boolean models in `.bnet` format.
- Compute the number of paths leading to the local states of a list of nodes.
- Perform model perturbations.
- Export back models to `.bnet`format.

## Instalation from PyPI:

To install BooLEVARD from PyPi, install the main package using pip:

```bash
pip install boolevard
```

The dependencies can be installed by running the following code:

```bash
pip install -r https://raw.githubusercontent.com/farinasm/boolevard/main/requirements.txt
```

## Installation with conda

To install BooLEVARD using conda, install the main package using conda:

```bash
conda install farinasm::boolevard
```

## Installation from source

To install the latest development version, BooLEVARD can also be installed from the source:

```bash
git clone https://github.com/farinasm/boolevard.git
cd boolevard
pip install .
pip install -r requirements.txt
```

## Documentation
For full BooLEVARD documentaiton visit our [GitHub Documentation](https://farinasm.github.io/boolevard) page.

A quick tutorial is available [here](https://github.com/farinasm/boolevard/tree/main/tutorial).

## Citing BooLEVARD and Contributors

*Citation not available. BooLEVARD has not been published and is not available as pre-print yet.* 

**Contributors:** Marco Fariñas, Eirini Tsirvouli, John Zobolas, Tero Aittokallio, Åsmund Flobak, Kaisa Lehti.

**Contact:** Marco Fariñas - farinasm.git@gmail.com
